@@ -41,8 +41,6 @@ class InvoiceLine(ModelSQL, ModelView):
             with_rec_name=with_rec_name)
 
     def read(self, ids, fields_names=None):
-        selection_obj = Pool().get('analytic_account.account.selection')
-
         int_id = False
         if isinstance(ids, (int, long)):
             int_id = True
@@ -72,7 +70,7 @@ class InvoiceLine(ModelSQL, ModelView):
             for line in lines:
                 for root_id in root_ids:
                     id2record[line.id]['analytic_account_' \
-                            + str(root_id)] = False
+                            + str(root_id)] = None
                 if line.type != 'line':
                     continue
                 if not line.analytic_accounts:
@@ -222,21 +220,24 @@ class Account(ModelSQL, ModelView):
     def delete(self, ids):
         account_invoice_line_obj = Pool().get('account.invoice.line')
         res = super(Account, self).delete(ids)
-        # Restart the cache on the fields_view_get method of account.invoice.line
+        # Restart the cache on the fields_view_get method of
+        # account.invoice.line
         account_invoice_line_obj.fields_view_get.reset()
         return res
 
     def create(self, vals):
         account_invoice_line_obj = Pool().get('account.invoice.line')
         res = super(Account, self).create(vals)
-        # Restart the cache on the fields_view_get method of account.invoice.line
+        # Restart the cache on the fields_view_get method of
+        # account.invoice.line
         account_invoice_line_obj.fields_view_get.reset()
         return res
 
     def write(self, ids, vals):
         account_invoice_line_obj = Pool().get('account.invoice.line')
         res = super(Account, self).write(ids, vals)
-        # Restart the cache on the fields_view_get method of account.invoice.line
+        # Restart the cache on the fields_view_get method of
+        # account.invoice.line
         account_invoice_line_obj.fields_view_get.reset()
         return res
 
